@@ -187,6 +187,11 @@ class Detection(ABC):
             self._setup_exception = TypeError(
                 "expected 'filters' to be of type Union[List[Filter], Filter, None]"
             )
+            self.logger.info(
+                "error while parsing filters for detection %s",
+                self.detection_id,
+                exc_info=self._setup_exception,
+            )
 
         self.skip_filters: bool = bool(config.get("skip_filters"))
 
@@ -281,6 +286,7 @@ class Detection(ABC):
                 detection_result.filter_output = all(f.filter(event) for f in self.filters)
         except Exception as err:  # pylint: disable=broad-except
             detection_result.filter_exception = err
+            self.logger.info("filters errored on detection %s", self.detection_id, exc_info=err)
 
         try:
             if detection_result.filters_did_not_match:
