@@ -41,7 +41,7 @@ def import_file_as_module(path: str, object_id: str) -> Any:
     """
 
     spec = import_util.spec_from_file_location(object_id, path)
-    mod = import_util.module_from_spec(spec)
+    mod = import_util.module_from_spec(spec)  # type: ignore
     spec.loader.exec_module(mod)  # type: ignore
     return mod
 
@@ -50,5 +50,5 @@ def store_modules(path: str, body: str) -> None:
     """Stores modules to disk."""
     # Create dir if it doesn't exist
     Path(os.path.dirname(path)).mkdir(parents=True, exist_ok=True)
-    with open(path, "w") as py_file:
+    with open(path, "w", encoding="utf-8") as py_file:
         py_file.write(body)
